
from mitoinstaller.jupyter_utils import get_prefered_jupyter_env_variable
from tests.conftest import VirtualEnvironment

def test_detects_notebook_as_prefered(venv: VirtualEnvironment):
    venv.run_python_module_command(['pip', 'install', 'notebook'])
    venv.run_python_module_command(['pip', 'install', '-r', 'requirements.txt'])
    out = venv.run_python_script('from mitoinstaller.jupyter_utils import get_prefered_jupyter_env_variable, set_prefered_jupyter_env_variable; set_prefered_jupyter_env_variable(); print(get_prefered_jupyter_env_variable())')
    assert out.strip() == 'notebook'

def test_defaults_to_lab(venv: VirtualEnvironment):
    venv.run_python_module_command(['pip', 'install', '-r', 'requirements.txt'])
    out = venv.run_python_script('from mitoinstaller.jupyter_utils import get_prefered_jupyter_env_variable, set_prefered_jupyter_env_variable; set_prefered_jupyter_env_variable(); print(get_prefered_jupyter_env_variable())')
    assert out.strip() == 'lab'


"""
The Mito Installer package contains utils for installing
Mito within your Python enviornment.

Long term, we aim to meet:
1. This package has minimal dependencies, both for speed of download and the ultimate portability.
2. The installation attempts to fail as early as possible, and to give the user as much help
   help as possible while doing so.
"""
from colorama import init
from termcolor import colored  # type: ignore

from mitoinstaller.install import do_install


def main() -> None:
    """
    The main function of the Mito installer, this function is responsible
    for installing and upgrading the `mitosheet` package.

    To install Mito:
    python -m mitoinstaller install

    To upgrade Mito:
    python -m mitoinstaller upgrade

    To install Mito from TestPyPi
    python -m mitoinstaller install --test-pypi
    """
    import sys
    init()

    if len(sys.argv) > 1:
        command = sys.argv[1]
    else:
        command = ''

    if command == 'install' or command == 'upgrade':
        do_install()
    elif command == 'uninstall':
        print('To uninstall, run,', colored('`pip uninstall mitosheet`', 'green'))
    else:
        # NOTE: we don't add upgrade_to_jupyterlab_3 to the help.
        # We only send this command to the users who need to know this (namely, those that need to upgrade)
        print('\nProper usage is', colored('`python -m mitoinstaller install`', 'green'), 'or', colored('`python -m mitoinstaller upgrade`', 'green'), '\n\nTry running the command ', colored('`python -m mitoinstaller install`', 'green'), '\n')
 

if __name__ == '__main__':
    main()




from time import perf_counter
from typing import Callable

from mitoinstaller.log_utils import log, log_error


class InstallerStep:
    """
    An installer step is a specific step in an install/upgrade process,
    that currently has a name and a function that executes when it runs.

    If you label a step as optional, then although this step may fail,
    it will not stop the InstallerSteps after it from executing.

    NOTE: install steps themselves should not log anything. All the logging
    is handeled by the run_installer_steps function, which dramatically
    clarifies when things go wrong.
    """
    def __init__(self, 
        installer_step_name: str, 
        execution_function: Callable,
        optional: bool=False,
        should_log_success: bool=False
    ):
        self.installer_step_name = installer_step_name
        self.execution_function = execution_function
        self.optional = optional
        self.should_log_success = should_log_success
        
    @property
    def event_name(self):
        return self.installer_step_name.replace(' ', '_').lower()
    
    def execute(self) -> None:
        self.execution_function()

    def log_success(self, start_time: float) -> None:
        processing_time = perf_counter() - start_time
        log(self.event_name + '_success', {
            'processing_time': round(processing_time, 1),
            'processing_time_seconds': round(processing_time, 0),
            'processing_time_seconds_ten': round(processing_time, -1),
            'processing_time_seconds_hundred': round(processing_time, -2),
        })
    
    def log_failure(self) -> None:
        log_error(self.event_name + '_failed')
